﻿using System; 
using System.Collections.Generic; 
using System.Linq; 
using System.Text; 

using PKTUSBAPI; 

namespace PKTUSBAPI_Concentrater_Demo 
{ 
    class Program 
    { 
        static void Main(string[] args) 
        { 
            try 
            {
                //Initialize the PKTUSBAPI (Show all existing PrehKeyTec USB Devices) 
                Console.WriteLine("\nInitialize the PKTUSBAPI");                 
                PKTUSBAPI_Class myAPI = new PKTUSBAPI_Class(null, true); 
                
                //Show the library versions 
                Console.WriteLine("PKTUSBAPI.dll Version: " + myAPI.VersionAPI); 
                Console.WriteLine("PKTUSBxx.dll Version: " + myAPI.VersionDLL);

                //Set up on received OCR data event for all devices 
                Console.WriteLine("\nSet up Event Handler: OnReceivedCommonOCR"); 
                myAPI.OnReceivedCommonOCR += new EventHandler<EventArguments.OnReceivedCommonOCR>(myAPI_OnReceivedCommonOCR);

                //Set up on received MSR data event for all devices 
                Console.WriteLine("\nSet up Event Handler: OnReceivedCommonMSR"); 
                myAPI.OnReceivedCommonMSR += new EventHandler<EventArguments.OnReceivedCommonMSR>(myAPI_OnReceivedCommonMSR);

                //Set up on received AUX data event for all devices 
                Console.WriteLine("\nSet up Event Handler: OnReceivedCommonAUX"); 
                myAPI.OnReceivedCommonAUX += new EventHandler<EventArguments.OnReceivedCommonAUX>(myAPI_OnReceivedCommonAUX);

                //Set up on received POS key event for all devices 
                Console.WriteLine("Set up Event Handler: OnReceivedCommonPOSkey"); 
                myAPI.OnReceivedCommonPOSkey += new EventHandler<EventArguments.OnReceivedCommonPOSkey>(myAPI_OnReceivedCommonPOSkey);

                //Set up on received key lock changed event for all devices
                Console.WriteLine("Set up Event Handler: OnCommonKeyLockChanged"); 
                myAPI.OnCommonKeyLockChanged += new EventHandler<EventArguments.OnCommonKeyLockChanged>(myAPI_OnCommonKeyLockChanged);

                while (true) ; 
            } 
            catch (Exception e) 
            { 
                Console.WriteLine(e.Message); 
            } 
        }
        
        static void myAPI_OnCommonKeyLockChanged(object sender, EventArguments.OnCommonKeyLockChanged e) 
        {
            //Show received event data 
            Console.WriteLine("\n[KeyLock] {" + e.Device.SerialNumber + "}"); 
            Console.WriteLine("Position: " + e.Data.Position); 
        } 
        
        static void myAPI_OnReceivedCommonPOSkey(object sender, EventArguments.OnReceivedCommonPOSkey e) 
        {
            //Show received event data 
            Console.WriteLine("\n[POS-Key] {" + e.Device.SerialNumber + "}");            
            Console.WriteLine("Key: " + e.Data.Key); 
            Console.WriteLine("Status: " + (e.Data.Pressed ? "pressed" : "released")); 
        } 
        
        static void myAPI_OnReceivedCommonMSR(object sender, EventArguments.OnReceivedCommonMSR e) 
        {
            //Show received event data 
            Console.WriteLine("\n[MSR] {" + e.Device.SerialNumber + "}"); 
            Console.WriteLine("Track 1: " + e.Data.MSRtrack1); 
            Console.WriteLine("Track 2: " + e.Data.MSRtrack2); 
            Console.WriteLine("Track 3: " + e.Data.MSRtrack3); 
        } 
        
        static void myAPI_OnReceivedCommonOCR(object sender, EventArguments.OnReceivedCommonOCR e) 
        {
            //Show received event data 
            Console.WriteLine("\n[OCR] {" + e.Device.SerialNumber + "}"); 
            Console.WriteLine("MRZ line 1: " + e.Data.MRZline1); 
            Console.WriteLine("MRZ line 2: " + e.Data.MRZline2); 
            Console.WriteLine("MRZ line 3: " + e.Data.MRZline3); 
        } 
        
        static void myAPI_OnReceivedCommonAUX(object sender, EventArguments.OnReceivedCommonAUX e) 
        {
            //Show received event data 
            Console.WriteLine("\n[AUX] {" + e.Device.SerialNumber + "}"); 
            Console.WriteLine("Data: " + e.Data.DataString); 
        }
    }
}