﻿#define MY_OCR_DEVICE // You can uncomment this Definition for non OCR devices using System; 

using System;
using System.Collections.Generic; 
using System.Linq; 
using System.Text; 
using System.Threading; 
using System.ComponentModel;

using PKTUSBAPI; //Reference to PKTUSBAPI.DLL 

namespace PKTUSBAPI_Console_Demo 
{ 
    class Program 
    { 
        private static PKTUSBAPI_Class myAPI = null; 
        private static USB_Device myDevice = null; 
#if MY_OCR_DEVICE 
        private static USB_Device myOCRDevice = null; 
#endif 
        static void Main(string[] args) 
        { 
            try 
            { 
                //Initialize the PKTUSBAPI (Show all existing PrehKeyTec USB Devices) 
                Console.WriteLine("\nInitialize the PKTUSBAPI"); 
                myAPI = new PKTUSBAPI_Class(null);

                //Show the library versions 
                Console.WriteLine("PKTUSBAPI.dll Version: " + myAPI.VersionAPI); 
                Console.WriteLine("PKTUSBxx.dll Version: " + myAPI.VersionDLL); 
                
                //Name of my log file (text file) 
                String LogFileName = "MyLogFile.txt";

                //Log only errors, warnings and inforamtion 
                int LogLevel = Constants.LOG_LEVEL_ERROR_WARNING_INFO; 
                
                //Append new messages to the log file if it already exists 
                bool LogAppend = true; 
                
                //Activate log file 
                int ret = myAPI.StartLog(LogFileName, LogAppend, LogLevel); 
                if (ret == ErrorStatus.Succeeded) 
                { 
                    Console.WriteLine("Logging successful started"); 
                } 
                else 
                { 
                    Console.WriteLine("Starting logging failed"); 
                } 
                
                // Open already connected device 
                OpenDevice(); 
#if MY_OCR_DEVICE 
                // Open already connected OCR device 
                OpenDeviceOCR(); 
#endif 
                //Set up on device status changed event 
                Console.WriteLine("\nSet up Event Handler: OnDeviceStatusChanged"); 
                myAPI.OnDeviceStatusChanged += new EventHandler<EventArguments.OnDeviceStatusChanged>(myAPI_OnDeviceStatusChanged); 
               
                while (true) ; 
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
            } 
        } 
        
        private static void OpenDevice() 
        { 
            //Open the device that was found first from the API with the usage page of 0xfffa 
            myDevice = myAPI.OpenDevice(0xfffa); 
            if (myDevice != null) 
            { 
                //Display some device information 
                Console.WriteLine("\n+ + + + + + + + + + + + + +"); 
                Console.WriteLine("Device opened:"); 
                Console.WriteLine(myDevice.DevicePath + "\n"); 
                Console.WriteLine(myDevice.VersionString); 
                //Play 'Beep' tone on it
                myDevice.PlayBeep(); 
                //Set up on received MSR data event for my device 
                Console.WriteLine("\nSet up Event Handler: OnReceivedMSR"); 
                myDevice.OnReceivedMSR += new EventHandler<EventArguments.OnReceivedMSR>(myDevice_OnReceivedMSR); 
                //Set up on received POS key event for my device 
                Console.WriteLine("Set up Event Handler: OnReceivedPOSkey"); 
                myDevice.OnReceivedPOSkey += new EventHandler<EventArguments.OnReceivedPOSkey>(myDevice_OnReceivedPOSkey);
                //Set up on received key lock changed event for my device 
                Console.WriteLine("Set up Event Handler: OnReceivedKeyLockChanged"); 
                myDevice.OnKeyLockChanged += new EventHandler<EventArguments.OnKeyLockChanged>(myDevice_OnKeyLockChanged); 
                Console.WriteLine("+ + + + + + + + + + + + + +"); 
            } 
        } 
#if MY_OCR_DEVICE 
        private static void OpenDeviceOCR() 
        { 
            //Open the device that was found first from the API with the usage page of 0xfff9 (OCR) 
            myOCRDevice = myAPI.OpenDevice(0xfff9); 
            if (myOCRDevice != null) 
            { 
                //Display some device information 
                Console.WriteLine("\n+ + + + + + + + + + + + + +"); 
                Console.WriteLine("OCR Device opened:"); 
                Console.WriteLine(myOCRDevice.DevicePath + "\n"); 
                Console.WriteLine(myOCRDevice.VersionString); 
                //Set up on received MSR data event for my device 
                Console.WriteLine("\nSet up Event Handler: OnReceivedMSR");
                myOCRDevice.OnReceivedMSR += new EventHandler<EventArguments.OnReceivedMSR>(myDevice_OnReceivedMSR); 
                //Set up on received OCR data event for my device 
                Console.WriteLine("Set up Event Handler: OnReceivedOCR"); 
                myOCRDevice.OnReceivedOCR += new EventHandler<EventArguments.OnReceivedOCR>(myDevice_OnReceivedOCR); 
                Console.WriteLine("+ + + + + + + + + + + + + +"); 
            } 
        }
#endif 
        static void myAPI_OnDeviceStatusChanged(object sender, EventArguments.OnDeviceStatusChanged e) 
        {
            //Do something only if a device was attached or detached 
            if (e.ConnectedStatusChanged) 
            { 
                //Check the usage page of the de-/attached device to see if it is a PrehKeyTec standard device 
                if (e.ChangedDevice.UsagePage == 0xfffa) 
                { 
                    //Check if myDevice was detached 
                    if (myDevice != null && e.ChangedDevice.DevicePath.Equals(myDevice.DevicePath) && !e.ChangedDevice.IsConnected) 
                    { 
                        //Close myDevice instance 
                        Console.WriteLine("\nDevice closed"); 
                        myDevice.Close(); myDevice = null; 
                    }
                    //Searching for a device to open if myDevice is 'null' 
                    if (myDevice == null) 
                    { 
                        OpenDevice(); 
                    } 
                } 
#if MY_OCR_DEVICE 
                //Check the usage page of the de-/attached device to see if it is a PrehKeyTec OCR device 
                if (e.ChangedDevice.UsagePage == 0xfff9) 
                { 
                    //Check if myOCRDevice was detached 
                    if (myOCRDevice != null && e.ChangedDevice.DevicePath.Equals(myOCRDevice.DevicePath) && !e.ChangedDevice.IsConnected) 
                    { 
                        //Close myOCRDevice instance 
                        Console.WriteLine("\nOCR Device closed"); 
                        myOCRDevice.Close(); 
                        myOCRDevice = null; 
                    } 
                    //Searching for an OCR device to open if myOCRDevice is 'null' 
                    if (myOCRDevice == null) 
                    { 
                        OpenDeviceOCR(); 
                    } 
                } 
#endif 
            } 
        } 
        
        static void myDevice_OnKeyLockChanged(object sender, EventArguments.OnKeyLockChanged e) 
        { 
            //Show received event data 
            Console.WriteLine("\n[KeyLock]"); 
            Console.WriteLine("Position: " + e.Position); 
        } 
        
        static void myDevice_OnReceivedPOSkey(object sender, EventArguments.OnReceivedPOSkey e) 
        { 
            //Show received event data 
            Console.WriteLine("\n[POS Key]"); 
            Console.WriteLine("Key: " + e.Key); 
            Console.WriteLine("Status: " + (e.Pressed ? "pressed" : "released")); 
        } 
        
        static void myDevice_OnReceivedMSR(object sender, EventArguments.OnReceivedMSR e) 
        { 
            //Show received event data 
            Console.WriteLine("\n[MSR]"); 
            Console.WriteLine("Track 1: " + e.MSRtrack1); 
            Console.WriteLine("Track 2: " + e.MSRtrack2); 
            Console.WriteLine("Track 3: " + e.MSRtrack3); 
        }

#if MY_OCR_DEVICE 
        static void myDevice_OnReceivedOCR(object sender, EventArguments.OnReceivedOCR e)
        { 
            //Show received event data 
            Console.WriteLine("\n[OCR]"); 
            Console.WriteLine("MRZ line 1: " + e.MRZline1); 
            Console.WriteLine("MRZ line 2: " + e.MRZline2); 
            Console.WriteLine("MRZ line 3: " + e.MRZline3); 
        } 
#endif 

    } 
}